==> contentsquare_platform_interface-0.2.1.tar.gz: test/src/types/gestures_test.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'package:contentsquare_platform_interface/contentsquare_platform_interface.dart';

void main() {
  group('$CSGesture', () {
    test('toInt should return 6 for "tap" gesture`', () {
      expect(CSGesture.tap.toInt(), 6);
    });
    test('toInt should return 6 for "long press" gesture`', () {
      expect(CSGesture.longPress.toInt(), 8);
    });
    test('toInt should return 6 for "drag" gesture`', () {
      expect(CSGesture.drag.toInt(), 9);
    });
    test('toInt should return 6 for "flick" gesture`', () {
      expect(CSGesture.flick.toInt(), 10);
    });
  });

  group('$CSGestureDirection', () {
    test('toInt should return 1 for "up" direction`', () {
      expect(CSGestureDirection.up.toInt(), 1);
    });
    test('toInt should return 2 for "down" direction`', () {
      expect(CSGestureDirection.down.toInt(), 2);
    });
    test('toInt should return 3 for "left" direction`', () {
      expect(CSGestureDirection.left.toInt(), 3);
    });
    test('toInt should return 4 for "right" direction`', () {
      expect(CSGestureDirection.right.toInt(), 4);
    });
  });

  group('TouchEventData', () {
    group('asMap', () {
      test('should return a map of the formatted touch event data', () {
        expect(
            TouchEventData(
              path: 'path/to/my/widget',
              gestureData: CSGestureData(
                  distance: 42,
                  direction: CSGestureDirection.left,
                  velocity: 86),
            ).asMap(),
            {
              'path': 'path/to/my/widget',
              'distance': 42,
              'direction': 3,
              'velocity': 86,
            });
      });
    });
  });
}

==> contentsquare_platform_interface-0.5.3.tar.gz: test/src/types/gestures_test.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'package:contentsquare_platform_interface/contentsquare_platform_interface.dart';

void main() {
  group('$CSGesture', () {
    test('toInt should return 6 for "tap" gesture`', () {
      expect(CSGesture.tap.toInt(), 6);
    });
    test('toInt should return 6 for "long press" gesture`', () {
      expect(CSGesture.longPress.toInt(), 8);
    });
    test('toInt should return 6 for "drag" gesture`', () {
      expect(CSGesture.drag.toInt(), 9);
    });
    test('toInt should return 6 for "flick" gesture`', () {
      expect(CSGesture.flick.toInt(), 10);
    });
  });

  group('$CSGestureDirection', () {
    test('toInt should return 1 for "up" direction`', () {
      expect(CSGestureDirection.up.toInt(), 1);
    });
    test('toInt should return 2 for "down" direction`', () {
      expect(CSGestureDirection.down.toInt(), 2);
    });
    test('toInt should return 3 for "left" direction`', () {
      expect(CSGestureDirection.left.toInt(), 3);
    });
    test('toInt should return 4 for "right" direction`', () {
      expect(CSGestureDirection.right.toInt(), 4);
    });
  });

  group('TouchEventData', () {
    group('asMap', () {
      test('should return a map of the formatted touch event data', () {
        expect(
            TouchEventData(
              path: 'path/to/my/widget',
              gestureData: const CSGestureData(
                  distance: 42,
                  direction: CSGestureDirection.left,
                  velocity: 86),
            ).asMap(),
            {
              'path': 'path/to/my/widget',
              'distance': 42,
              'direction': 3,
              'velocity': 86,
            });
      });
    });
  });
}
